package
Version:
v0.0.0-...-76c6153
Opens a new window with list of versions in this module.
Published: Aug 3, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BasicResponse struct {
Ok bool `json:"ok"`
Details string `json:"details"`
Timestamp time.Time `json:"timestamp"`
}
type CreateCommentDto struct {
}
type CreatePostRequest struct {
Title string `json:"title" binding:"required,min=2"`
Content string `json:"content" binding:"required,min=100,max=15000"`
FeedView string `json:"feed_view" binding:"required,min=100,max=2000"`
Tags []string `json:"tags"`
}
type EditPostRequest struct {
PostID int64 `json:"id"`
AuthorID uuid.UUID `json:"author_id"`
Title *string `json:"title"`
Content *string `json:"content"`
FeedView *string `json:"feed_view"`
}
type GetCommentsDto struct {
}
type GetPost struct {
Post model.FullPost `json:"post"`
IsLiked bool `json:"is_liked"`
}
type GetPostsRequest struct {
Limit int `json:"limit"`
Offset int `json:"offset"`
}
type MQPostCreatedMsg struct {
PostID int64 `json:"post_id"`
UserID uuid.UUID `json:"user_id"`
PostTitle string `json:"post_title"`
CreatedAt time.Time `json:"created_at"`
}
type MQPostValidationStatusUpdateMsg struct {
PostID int64 `json:"post_id"`
UserID uuid.UUID `json:"user_id"`
StatusMsg string `json:"status_msg"`
}
type UpdatePostValidationStatusRequest struct {
PostID int64 `json:"post_id" binding:"required"`
Validated bool `json:"validated" binding:"required"`
StatusMsg string `json:"status_msg" binding:"required,max=1024"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.